PaymentResult class

Annotations

Constructors

PaymentResult({required bool success, required String status, required String finalUrl, String? transactionId, String? message})
const
PaymentResult.cancelled({required String finalUrl, String? message})
factory
PaymentResult.invalidRequest({String? message})
factory

Properties

finalUrl String
final
hashCode int
The hash code for this object.
no setteroverride
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
success bool
final
transactionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override